import { AxiosResponse } from 'axios';
import { apiClient } from '../lib/apiClient';
import { Profile } from '../types/profile';
import { Session, SessionsFilter } from '../types/sessions';

export const setPersonData = (person: { login: string, password: string, role: string, languagesLinks: any[] }, locale: string, jwt: string): Promise<AxiosResponse<{ userData: Profile }>> => (
    apiClient.post(
        '/home/applyperson1',
        { ...person },
        {
            headers: {
                'X-User-Language': locale,
                Authorization: `Bearer ${jwt}`
            }
        }
    )
);

export const getPersonalData = (locale: string, jwt: string): Promise<AxiosResponse<Profile>> => (
    apiClient.post(
        '/home/userdata',
        {},
        {
            headers: {
                'X-User-Language': locale,
                Authorization: `Bearer ${jwt}`
            }
        }
    )
);

export const getUpcomingSessions = (locale: string, jwt: string, filter?: SessionsFilter): Promise<AxiosResponse<Session[]>> => (
    apiClient.post(
        '/home/upcomingsessionsall',
        {
            sessionType: 'session',
            ...(filter || {})
        },
        {
            headers: {
                'X-User-Language': locale,
                Authorization: `Bearer ${jwt}`
            }
        }
    )
);

export const getRequestedSessions = (locale: string, jwt: string): Promise<AxiosResponse<{ requestedSessions: Session[] }>> => (
    apiClient.post(
        '/home/coachhomedata',
        {},
        {
            headers: {
                'X-User-Language': locale,
                Authorization: `Bearer ${jwt}`
            }
        }
    )
);

export const getRecentSessions = (locale: string, jwt: string, filter?: SessionsFilter): Promise<AxiosResponse<Session[]>> => (
    apiClient.post(
        '/home/historicalmeetings',
        {
            sessionType: 'session',
            ...(filter || {})
        },
        {
            headers: {
                'X-User-Language': locale,
                Authorization: `Bearer ${jwt}`
            }
        }
    )
);

export const getSessionDetails = (locale: string, jwt: string, id: number): Promise<AxiosResponse<Session>> => (
    apiClient.post(
        '/home/session',
        { id },
        {
            headers: {
                'X-User-Language': locale,
                Authorization: `Bearer ${jwt}`
            }
        }
    )
);
