'use client'

import React, { ReactNode } from 'react';
import { AccountMenu } from '../../../../components/Account';
import { i18nText } from '../../../../i18nKeys';

type AccountInnerLayoutProps = {
    children: ReactNode;
    params: { locale: string };
};

const ROUTES = ['sessions', 'notifications', 'support', 'information', 'settings', 'messages', 'work-with-us'];
const COUNTS: Record<string, number> = {
    sessions: 12,
    notifications: 5,
    messages: 113
};


export default function AccountInnerLayout({ children, params: { locale } }: AccountInnerLayoutProps) {
    const getMenuConfig = () => ROUTES.map((path) => ({
        path,
        title: i18nText(`accountMenu.${path}`, locale),
        count: COUNTS[path] || undefined
    }));

    return (
        <div className="page-account">
            <div className="b-inner">
                <div className="row">
                    <div className="col-xl-3 col-lg-4 d-none d-lg-block">
                        <AccountMenu menu={getMenuConfig()} locale={locale} />
                    </div>
                    <div className="col-xl-9 col-lg-8 ">
                        <div className="page-account__inner">
                            {children}
                        </div>
                    </div>
                </div>
            </div>
        </div>
    );
};
